@@ -19,7 +19,7 @@
 
 #include "cheese-config.h"
 
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <clutter-gst/clutter-gst.h>
 
 #include "cheese-widget.h"
